@@ -10,14 +10,13 @@ from multiprocessing import Process, Queue
 
 class Parser(object):
 
-    title = ""
-    description = ""
-    permalink = ""
-    updated = ""
-    author = ""
-    items = []
-
     def __init__(self, uri, cache_time=600):
+        self.title = ""
+        self.description = ""
+        self.permalink = ""
+        self.updated = ""
+        self.author = ""
+        self.items = []
         cache = Cache()
         if type(uri) != str:
             raise TypeError("value must be string!")
@@ -324,11 +323,3 @@ class Parser(object):
             util.log_file(
                 self.__log_path, "headerDescription: no model is matching!\n---\n%s" % item, "warning")
         return ""
-
-    def close(self):
-        self.title = ""
-        self.description = ""
-        self.permalink = ""
-        self.updated = ""
-        self.author = ""
-        self.items = []
